@@ -174,6 +174,9 @@ ProcessOtherEvent(xEventPtr xE, register DeviceIntPtr other, int count)
 	}
 
     if (xE->u.u.type == DeviceKeyPress) {
+        if (!k)
+            return;
+
 	modifiers = k->modifierMap[key];
 	kptr = &k->down[key >> 3];
 	if (*kptr & bit) {	/* allow ddx to generate multiple downs */
@@ -203,6 +206,9 @@ ProcessOtherEvent(xEventPtr xE, register DeviceIntPtr other, int count)
 	    return;
 	}
     } else if (xE->u.u.type == DeviceKeyRelease) {
+        if (!k)
+            return;
+
 	kptr = &k->down[key >> 3];
 	if (!(*kptr & bit))	/* guard against duplicates */
 	    return;
@@ -225,6 +231,9 @@ ProcessOtherEvent(xEventPtr xE, register DeviceIntPtr other, int count)
 	if (other->fromPassiveGrab && (key == other->activatingKey))
 	    deactivateDeviceGrab = TRUE;
     } else if (xE->u.u.type == DeviceButtonPress) {
+        if (!b)
+            return;
+
 	kptr = &b->down[key >> 3];
 	*kptr |= bit;
 	if (other->valuator)
@@ -242,6 +251,9 @@ ProcessOtherEvent(xEventPtr xE, register DeviceIntPtr other, int count)
 		return;
 
     } else if (xE->u.u.type == DeviceButtonRelease) {
+        if (!b)
+            return;
+
 	kptr = &b->down[key >> 3];
 	*kptr &= ~bit;
 	if (other->valuator)
@@ -655,8 +667,10 @@ AddExtensionClient(WindowPtr pWin, ClientPtr client, Mask mask, int mskidx)
     others = (InputClients *) malloc(sizeof(InputClients));
     if (!others)
 	return BadAlloc;
-    if (!pWin->optional->inputMasks && !MakeInputMasks(pWin))
+    if (!pWin->optional->inputMasks && !MakeInputMasks(pWin)) {
+	free(others);
 	return BadAlloc;
+    }
     bzero((char *)&others->mask[0], sizeof(Mask) * EMASKSIZE);
     others->mask[mskidx] = mask;
     others->resource = FakeClientID(client->index);
@@ -1073,6 +1087,9 @@ MaybeSendDeviceMotionNotifyHint(deviceKeyButtonPointer * pEvents, Mask mask)
     DeviceIntPtr dev;
 
     dev = LookupDeviceIntRec(pEvents->deviceid & DEVICE_BITS);
+    if (!dev)
+        return 0;
+
     if (pEvents->type == DeviceMotionNotify) {
 	if (mask & DevicePointerMotionHintMask) {
 	    if (WID(dev->valuator->motionHintWindow) == pEvents->event) {
@@ -1094,6 +1111,9 @@ CheckDeviceGrabAndHintWindow(WindowPtr pWin, int type,
     DeviceIntPtr dev;
 
     dev = LookupDeviceIntRec(xE->deviceid & DEVICE_BITS);
+    if (!dev)
+        return;
+
     if (type == DeviceMotionNotify)
 	dev->valuator->motionHintWindow = pWin;
     else if ((type == DeviceButtonPress) && (!grab) &&
