@@ -53,24 +53,16 @@
 #include "regionstr.h"
 #include "gcstruct.h"
 #include "inputstr.h"
+#include "midbe.h"
 
 #include <stdio.h>
 
-/* DEFINES */
-
-
-/* TYPEDEFS */
-
-
-/* GLOBALS */
-
 static int	miDbePrivPrivGeneration  =  0;
 static int	miDbeWindowPrivPrivIndex = -1;
-RESTYPE		dbeDrawableResType;
-RESTYPE		dbeWindowPrivResType;
-int		dbeScreenPrivIndex = -1;
-int		dbeWindowPrivIndex = -1;
-
+static RESTYPE	dbeDrawableResType;
+static RESTYPE	dbeWindowPrivResType;
+static int	dbeScreenPrivIndex = -1;
+static int	dbeWindowPrivIndex = -1;
 
 
 /******************************************************************************
@@ -90,9 +82,7 @@ int		dbeWindowPrivIndex = -1;
  *****************************************************************************/
 
 static Bool
-miDbeGetVisualInfo(pScreen, pScrVisInfo)
-    ScreenPtr			pScreen;
-    XdbeScreenVisualInfo	*pScrVisInfo;
+miDbeGetVisualInfo(ScreenPtr pScreen, XdbeScreenVisualInfo *pScrVisInfo)
 {
     register int	i, j, k;
     register int	count;
@@ -154,10 +144,7 @@ miDbeGetVisualInfo(pScreen, pScrVisInfo)
  *****************************************************************************/
 
 static int
-miDbeAllocBackBufferName(pWin, bufId, swapAction)
-    WindowPtr		pWin;
-    XID			bufId;
-    int			swapAction;
+miDbeAllocBackBufferName(WindowPtr pWin, XID bufId, int swapAction)
 {
     ScreenPtr			pScreen;
     DbeWindowPrivPtr		pDbeWindowPriv;
@@ -268,8 +255,7 @@ miDbeAllocBackBufferName(pWin, bufId, swapAction)
  *****************************************************************************/
 
 static void
-miDbeAliasBuffers(pDbeWindowPriv)
-    DbeWindowPrivPtr	pDbeWindowPriv;
+miDbeAliasBuffers(DbeWindowPrivPtr pDbeWindowPriv)
 {
     int				i;
     MiDbeWindowPrivPrivPtr	pDbeWindowPrivPriv =
@@ -295,10 +281,7 @@ miDbeAliasBuffers(pDbeWindowPriv)
  *****************************************************************************/
 
 static int
-miDbeSwapBuffers(client, pNumWindows, swapInfo)
-    ClientPtr		client;
-    int			*pNumWindows;
-    DbeSwapInfoPtr	swapInfo;
+miDbeSwapBuffers(ClientPtr client, int *pNumWindows, DbeSwapInfoPtr swapInfo)
 {
     DbeScreenPrivPtr		pDbeScreenPriv;
     GCPtr		    	pGC;
@@ -477,9 +460,7 @@ miDbeSwapBuffers(client, pNumWindows, swapInfo)
  *****************************************************************************/
 
 static void
-miDbeWinPrivDelete(pDbeWindowPriv, bufId)
-    DbeWindowPrivPtr	pDbeWindowPriv;
-    XID			bufId;
+miDbeWinPrivDelete(DbeWindowPrivPtr pDbeWindowPriv, XID bufId)
 {
     MiDbeWindowPrivPrivPtr	pDbeWindowPrivPriv;
 
@@ -526,10 +507,7 @@ miDbeWinPrivDelete(pDbeWindowPriv, bufId)
  *****************************************************************************/
 
 static Bool
-miDbePositionWindow(pWin, x, y)
-    WindowPtr	pWin;
-    int		x;
-    int		y;
+miDbePositionWindow(WindowPtr pWin, int x, int y)
 {
     ScreenPtr			pScreen;
     DbeScreenPrivPtr		pDbeScreenPriv;
@@ -767,8 +745,7 @@ miDbePositionWindow(pWin, x, y)
  *****************************************************************************/
 
 static void
-miDbeResetProc(pScreen)
-    ScreenPtr	pScreen;
+miDbeResetProc(ScreenPtr pScreen)
 {
     DbeScreenPrivPtr    pDbeScreenPriv;
 
@@ -792,9 +769,7 @@ miDbeResetProc(pScreen)
  *****************************************************************************/
 
 Bool
-miDbeInit(pScreen, pDbeScreenPriv)
-    ScreenPtr		pScreen;
-    DbeScreenPrivPtr	pDbeScreenPriv;
+miDbeInit(ScreenPtr pScreen, DbeScreenPrivPtr pDbeScreenPriv)
 {
     /* Copy resource types created by DIX */
     dbeDrawableResType   = pDbeScreenPriv->dbeDrawableResType;
@@ -839,9 +814,6 @@ miDbeInit(pScreen, pDbeScreenPriv)
     pDbeScreenPriv->ResetProc             = miDbeResetProc;
     pDbeScreenPriv->WinPrivDelete         = miDbeWinPrivDelete;
 
-    /* The mi implementation doesn't need buffer validation. */
-    pDbeScreenPriv->ValidateBuffer	  = (void (*)())NoopDDA;
-
     return(TRUE);
 
 } /* miDbeInit() */
