@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -187,9 +187,8 @@ int ddxProcessArgument(int argc, char *argv[], int i)
   /*
    * The flavour can never change, so only set it once.
    *
-   * FIXME: ddxProcessArgument() is called once for every command line
-   * argument, with argv[0] being the argument and not the program
-   * name! We should move this check somewhere else.
+   * ddxProcessArgument() is called once for every command line
+   * argument, with argv[i] being the argument, i > 0. argv[0] is the program name.
    */
   if (nxagentProgName == NULL)
   {
@@ -197,10 +196,12 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     nxagentProgName = strdup(basename(basec));
     SAFE_free(basec);
 
+#ifdef X2GO
     /*
      * Check if we are running as X2Go Agent
      */
-    checkX2goAgent();
+    checkX2goAgent(argc, argv);
+#endif
   }
 
   #ifdef TEST
@@ -266,7 +267,6 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     if (envOptions != NULL)
     {
       nxagentParseOptionString(envOptions);
-
       SAFE_free(envOptions);
     }
 
@@ -480,7 +480,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
       return 2;
     }
     return 0;
-  } 
+  }
 
   if (!strcmp(argv[i], "-streaming"))
   {
@@ -542,7 +542,7 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     if (++i < argc &&
             sscanf(argv[i], "%ix%i", &width, &height) == 2 &&
                 width >= 32 && height >= 32)
-    { 
+    {
       nxagentChangeOption(TileWidth,  width);
       nxagentChangeOption(TileHeight, height);
       return 2;
@@ -582,13 +582,13 @@ int ddxProcessArgument(int argc, char *argv[], int i)
         nxagentChangeOption(AllScreens, False);
       }
       else
-      { 
-        if (nxagentUserGeometry.flag == 0) 
+      {
+        if (nxagentUserGeometry.flag == 0)
         {
-          nxagentUserGeometry.flag = XParseGeometry(argv[i], 
-                                                        &nxagentUserGeometry.X, 
-                                                            &nxagentUserGeometry.Y, 
-                                                                &nxagentUserGeometry.Width, 
+          nxagentUserGeometry.flag = XParseGeometry(argv[i],
+                                                        &nxagentUserGeometry.X,
+                                                            &nxagentUserGeometry.Y,
+                                                                &nxagentUserGeometry.Width,
                                                                     &nxagentUserGeometry.Height);
         }
       }
@@ -691,16 +691,16 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     {
       SAFE_free(nxagentKeyboard);
 
+#ifdef X2GO
       if (nxagentX2go && strcmp(argv[i], "null/null") == 0)
       {
         #ifdef TEST
         fprintf(stderr, "%s: changing nxagentKeyboard from [null/null] to [clone].\n", __func__);
         #endif
-
-        SAFE_free(nxagentKeyboard);
         nxagentKeyboard = strdup("clone");
       }
       else
+#endif
       {
         nxagentKeyboard = strdup(argv[i]);
       }
@@ -733,6 +733,14 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 1;
   }
 
+  /* the composite extension is disabled by default so we provide a
+     way to enable it */
+  if (!strcmp(argv[i], "-composite"))
+  {
+    nxagentChangeOption(Composite, True);
+    return 1;
+  }
+
   if (!strcmp(argv[i], "-nodamage"))
   {
     nxagentChangeOption(UseDamage, False);
@@ -960,6 +968,12 @@ int ddxProcessArgument(int argc, char *argv[], int i)
     return 2;
   }
 
+  if (!strcmp(argv[i], "-textclipboard"))
+  {
+    nxagentChangeOption(TextClipboard, True);
+    return 1;
+  }
+
   if (!strcmp(argv[i], "-bs"))
   {
     nxagentChangeOption(BackingStore, BackingStoreNever);
@@ -1136,7 +1150,6 @@ static void nxagentParseSingleOption(char *name, char *value)
       fprintf(stderr, "Warning: Ignoring bad value '%s' for option 'fullscreen'.\n",
                   validateString(value));
     }
-
     return;
   }
   else if (!strcmp(name, "shpix"))
@@ -1171,7 +1184,6 @@ static void nxagentParseSingleOption(char *name, char *value)
       fprintf(stderr, "Warning: Ignoring bad value '%s' for option 'shmem'.\n",
                   validateString(value));
     }
-
     return;
   }
   else if (!strcmp(name, "composite"))
@@ -1475,6 +1487,18 @@ static void nxagentParseSingleOption(char *name, char *value)
     }
     return;
   }
+  else if (!strcmp(name, "textclipboard"))
+  {
+    if (!strcmp(value, "0"))
+    {
+      nxagentChangeOption(TextClipboard, False);
+    }
+    else
+    {
+      nxagentChangeOption(TextClipboard, True);
+    }
+    return;
+  }
   else
   {
     #ifdef DEBUG
@@ -1501,7 +1525,6 @@ static void nxagentParseSingleOption(char *name, char *value)
     }
 
     *argv[0] = '-';
-
     memcpy(argv[0] + 1, name, size);
   }
 
@@ -1775,11 +1798,13 @@ N/A
 
     if (*nxagentWindowName == '\0')
     {
-      if(nxagentX2go)
+#ifdef X2GO
+      if (nxagentX2go)
       {
         snprintf(nxagentWindowName, NXAGENTWINDOWNAMELENGTH, "X2Go Agent");
       }
       else
+#endif
       {
         snprintf(nxagentWindowName, NXAGENTWINDOWNAMELENGTH, "NX Agent");
       }
@@ -1870,11 +1895,11 @@ N/A
         fprintf(stderr, "nxagentPostProcessArgs: WARNING! Using backward compatible alpha encoding.\n");
         #endif
 
-        nxagentAlphaCompat = 1;
+        nxagentAlphaCompat = True;
       }
       else
       {
-        nxagentAlphaCompat = 0;
+        nxagentAlphaCompat = False;
       }
 
       nxagentRemoteMajor = remoteMajor;
@@ -1984,28 +2009,28 @@ FIXME: In rootless mode the backing-store support is not functional yet.
 */
     if (nxagentOption(Rootless))
     {
-      enableBackingStore = 0;
+      enableBackingStore = FALSE;
     }
     else if (nxagentOption(BackingStore) == BackingStoreUndefined ||
                  nxagentOption(BackingStore) == BackingStoreForce)
     {
-      enableBackingStore = 1;
+      enableBackingStore = TRUE;
     }
     else if (nxagentOption(BackingStore) == BackingStoreNever)
     {
-      enableBackingStore = 0;
+      enableBackingStore = FALSE;
     }
 
     /*
      * need to check if this was set on the command line as this has
      * the priority over the option file.
      */
- 
+
     if (nxagentRenderEnable == UNDEFINED)
     {
       nxagentRenderEnable = True;
     }
-    
+
     if (nxagentRenderEnable == True)
     {
       nxagentAlphaEnabled = True;
@@ -2098,9 +2123,13 @@ void ddxUseMsg(void)
   ErrorF("-autodpi               detect real server's DPI and use that in the session\n");
   ErrorF("-display string        display name of the real server\n");
   ErrorF("-sync                  synchronize with the real server\n");
+  ErrorF("-nxrealwindowprop      set property NX_REAL_WINDOW for each X11 window inside nxagent\n");
+  ErrorF("-reportwids            report externally exposed X11 window IDs to the session log\n");
+  ErrorF("-reportprivatewids     report internal X11 window ID to the session log\n");
 #ifdef RENDER
   ErrorF("-norender              disable the use of the render extension\n");
-  ErrorF("-nocomposite           disable the use of the composite extension\n");
+  ErrorF("-nocomposite           disable the use of the composite extension (default)\n");
+  ErrorF("-composite             enable the use of the composite extension\n");
 #endif
   ErrorF("-nopersistent          disable disconnection/reconnection to the X display on SIGHUP\n");
   ErrorF("-noshmem               disable use of shared memory extension\n");
@@ -2111,9 +2140,11 @@ void ddxUseMsg(void)
   ErrorF("-nokbreset             don't reset keyboard device if the session is resumed\n");
   ErrorF("-noxkblock             always allow applications to change layout through XKEYBOARD\n");
   ErrorF("-autograb              enable autograb\n");
+  ErrorF("-textclipboard         limit clipboard data to text only\n");
   ErrorF("-irlimit               maximum image data rate to the encoder input in kB/s.\n");
   ErrorF("-tile WxH              maximum size of image tiles (minimum allowed: 32x32)\n");
   ErrorF("-keystrokefile file    file with keyboard shortcut definitions\n");
+  ErrorF("-options file|string   path to an options file or an option string (for testing/debugging)\n");
   ErrorF("-verbose               print more warning and error messages\n");
   ErrorF("-D                     enable desktop mode\n");
   ErrorF("-R                     enable rootless mode\n");
@@ -2185,7 +2216,7 @@ void nxagentSetPackMethod(void)
 
     nxagentChangeOption(Adaptive, False);
   }
-  
+
   if (method == PACK_LOSSY || method == PACK_ADAPTIVE)
   {
     nxagentPackMethod = PACK_JPEG_16M_COLORS;
@@ -2402,7 +2433,7 @@ void nxagentSetDeferLevel(void)
   /*
    * Set the tile height.
    */
-  
+
   if (nxagentOption(TileHeight) != UNDEFINED)
   {
     #ifdef TEST
