@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -76,7 +76,7 @@ Atom nxagentAtoms[NXAGENT_NUMBER_OF_ATOMS];
  * Careful! Do not change indices here! Some of those are referenced
  * at other places via nxagentAtoms[index].
  */
-static char *nxagentAtomNames[NXAGENT_NUMBER_OF_ATOMS + 1] =
+static char *nxagentAtomNames[NXAGENT_NUMBER_OF_ATOMS + 2] =
 {
   "NX_IDENTITY",                 /*  0 */
       /* NX_IDENTITY was used in earlier nx versions to communicate
@@ -89,9 +89,12 @@ static char *nxagentAtomNames[NXAGENT_NUMBER_OF_ATOMS + 1] =
   "WM_NX_READY",                 /*  3 */
       /* nxagent takes the ownership of the selection with this name
          to signal the nxclient (or any other watching program)
-         it is ready. */
+         it is ready. This is only used if NXAGENT_ONSTART is defined.
+         We cannot enclose it in #ifdef here because we use the numeric
+         indices to this structure at multiple places. */
   "MCOPGLOBALS",                 /*  4 */
-      /* used for artsd support. */
+      /* used for artsd support. Only used if compiled with
+         NXAGENT_ARTSD */
   "NX_CUT_BUFFER_SERVER",        /*  5 */
       /* this is the name of a property on nxagent's window on the
          real X server. This property is used for passing clipboard
@@ -132,6 +135,27 @@ static char *nxagentAtomNames[NXAGENT_NUMBER_OF_ATOMS + 1] =
   "COMPOUND_TEXT",               /* 16 */
       /* one of the supported data formats for selections. Standard
          ICCCM Atom */
+  "INCR",                        /* 17 */
+      /* incremental clipboard transfers. Standard
+         ICCCM Atom */
+  "MULTIPLE",                    /* 18 */
+      /* request selection in multiple formats at once. Standard
+         ICCCM Atom */
+  "DELETE",                      /* 19 */
+      /* request to delete selection. Standard ICCCM Atom */
+  "INSERT_SELECTION",            /* 20 */
+      /* request to insert other selection. Standard ICCCM Atom */
+  "INSERT_PROPERTY",             /* 21 */
+      /* request to insert content of property into selection. Standard
+         ICCCM Atom */
+  "SAVE_TARGETS",                /* 22 */
+      /* request to save clipboard content to clipboard manager on
+	 exit, see
+	 https://www.freedesktop.org/wiki/ClipboardManager */
+  "TARGET_SIZES",                /* 23 */
+      /* request to retrieve the sizes of the clipboard content in
+	 various formats, see
+	 https://www.freedesktop.org/wiki/ClipboardManager */
   NULL,
   NULL
 };
@@ -201,7 +225,7 @@ static void finishWMDetection(Bool verbose)
   }
 }
 
-void nxagentWMDetect() 
+void nxagentWMDetect()
 {
   /* FIXME: verbose is always false, there's no code to set it to true */
   Bool verbose = False;
@@ -484,7 +508,7 @@ static void nxagentInitAtomMap(char **atomNameList, int count, Atom *atomsRet)
     name_list[i] = atomNameList[i];
     atom_list[i] = None;
   }
-  
+
   for (unsigned int i = 0; i < privLastAtom; i++)
   {
     name_list[count + i] = (char *)privAtomMap[i].string;
@@ -599,7 +623,7 @@ static AtomMap* nxagentFindAtomByName(char *string, unsigned int length)
 {
   for (unsigned int i = 0; i < privLastAtom; i++)
   {
-    if ((length == privAtomMap[i].length) && 
+    if ((length == privAtomMap[i].length) &&
             (strcmp(string, privAtomMap[i].string) == 0))
     {
       return (privAtomMap + i);
@@ -747,6 +771,54 @@ XlibAtom nxagentLocalToRemoteAtom(Atom local)
   }
 }
 
+/*
+ * This is mainly used to simplify debug prints. It returns
+ * the string for a remote atom or NULL if atom is unknown/invalid
+ *
+ * The string must NOT be freed by the caller.
+ */
+const char *nxagentRemoteAtomToString(XlibAtom remote)
+{
+  if (remote == None || remote == BAD_RESOURCE)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: remote [%d] is None or BAD_RESOURCE\n", __func__, remote);
+    #endif
+    return NULL;
+  }
+
+  /* no mapping required for built-in atoms */
+  if (remote <= XA_LAST_PREDEFINED)
+  {
+    #ifdef DEBUG
+    fprintf(stderr, "%s: remote [%d] is <= XA_LAST_PREDEFINED [%d]\n", __func__, remote, XA_LAST_PREDEFINED);
+    #endif
+
+    /* simply use the builtin string that is the same on every X server */
+    return NameForAtom(remote);
+  }
+
+  AtomMap *current = nxagentFindAtomByRemoteValue(remote);
+  if (current)
+  {
+    return current->string;
+  }
+  else
+  {
+    /* fill up the cache */
+    Atom local = nxagentRemoteToLocalAtom(remote);
+    if (local != None)
+    {
+      current = nxagentFindAtomByRemoteValue(remote);
+      if (current)
+      {
+        return current->string;
+      }
+    }
+  }
+  return NULL;
+}
+
 Atom nxagentRemoteToLocalAtom(XlibAtom remote)
 {
   if (remote == None || remote == BAD_RESOURCE)
