@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -47,7 +47,7 @@
  * Set if the composite extension is supported by the remote display.
  */
 
-int nxagentCompositeEnable = UNDEFINED;
+Bool nxagentCompositeEnable = False;
 
 void nxagentCompositeExtensionInit(void)
 {
@@ -55,7 +55,7 @@ void nxagentCompositeExtensionInit(void)
    * Set the flag only if the initialization completes.
    */
 
-  nxagentCompositeEnable = 0;
+  nxagentCompositeEnable = False;
 
   if (nxagentOption(Composite))
   {
@@ -96,7 +96,7 @@ void nxagentCompositeExtensionInit(void)
       fprintf(stderr, "nxagentCompositeExtensionInit: Enabling the use of the composite extension.\n");
       #endif
 
-      nxagentCompositeEnable = 1;
+      nxagentCompositeEnable = True;
     }
     #ifdef TEST
     else
@@ -115,8 +115,7 @@ void nxagentCompositeExtensionInit(void)
 
 void nxagentRedirectDefaultWindows(void)
 {
-  if (nxagentOption(Rootless) ||
-          nxagentCompositeEnable == 0)
+  if (nxagentOption(Rootless) || !nxagentCompositeEnable)
   {
     #ifdef TEST
     fprintf(stderr, "nxagentRedirectDefaultWindows: Not redirecting default "
@@ -140,13 +139,13 @@ void nxagentRedirectDefaultWindows(void)
 
     /*
      * When trying to redirect only the top level window, and not the
-     * subwindows, we incur in a strange be- haviour. The top level is
-     * unmapped, mapped, unmap- ped and then reparented. This at first
+     * subwindows, we incur in a strange behaviour. The top level is
+     * unmapped, mapped, unmapped and then reparented. This at first
      * makes the agent think that the window manager is gone, then the
-     * agent window disappears. To make thinks even more weird, this
+     * agent window disappears. To make things even more weird, this
      * happens only at reconnection.
      */
- 
+
     XCompositeRedirectSubwindows(nxagentDisplay, nxagentDefaultWindows[pScreen->myNum],
                                      CompositeRedirectAutomatic);
   }
@@ -154,8 +153,7 @@ void nxagentRedirectDefaultWindows(void)
 
 void nxagentRedirectWindow(WindowPtr pWin)
 {
-  if (!nxagentOption(Rootless) ||
-          nxagentCompositeEnable == 0)
+  if (!nxagentOption(Rootless) || !nxagentCompositeEnable)
   {
     #ifdef TEST
     fprintf(stderr, "nxagentRedirectWindow: Not redirecting window id [%ld] "
