@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -87,8 +87,8 @@ int nxagentSplitThreshold = -1;
  * Set if images can use the alpha channel.
  */
 
-int nxagentAlphaEnabled = 0;
-int nxagentAlphaCompat  = 0;
+Bool nxagentAlphaEnabled = False;
+Bool nxagentAlphaCompat = False;
 
 /*
  * Used to reformat image when connecting to displays having different
@@ -418,7 +418,7 @@ FIXME: Here the split trap is always set and so the caching of the
      * send the alpha data in compressed form.
      */
 
-    if (nxagentAlphaCompat == 0)
+    if (!nxagentAlphaCompat)
     {
       NXSetUnpackAlpha(nxagentDisplay, resource, PACK_NONE, size, data, size);
     }
@@ -526,7 +526,7 @@ void nxagentPutImage(DrawablePtr pDrawable, GCPtr pGC, int depth,
 
   if (!nxagentOption(IgnoreVisibility) && pDrawable -> type == DRAWABLE_WINDOW &&
           (!nxagentWindowIsVisible((WindowPtr) pDrawable) ||
-              (!nxagentDefaultWindowIsVisible() && nxagentCompositeEnable == 0)))
+              (!nxagentDefaultWindowIsVisible() && !nxagentCompositeEnable)))
   {
 
     #ifdef TEST
@@ -629,7 +629,7 @@ FIXME: Should use these.
                         pRegion -> extents.y1, pRegion -> extents.x2, pRegion -> extents.y2,
                             (void *) pDrawable);
         #endif
-  
+
         nxagentMarkCorruptedRegion(pDrawable, pRegion);
 
         goto nxagentPutImageEnd;
@@ -647,7 +647,7 @@ FIXME: Should use these.
                       pRegion -> extents.y1, pRegion -> extents.x2, pRegion -> extents.y2,
                           (void *) pDrawable);
       #endif
-  
+
       nxagentMarkCorruptedRegion(pDrawable, pRegion);
 
       goto nxagentPutImageEnd;
@@ -915,9 +915,9 @@ void nxagentRealizeImage(DrawablePtr pDrawable, GCPtr pGC, int depth,
     #ifdef WARNING
     fprintf(stderr, "nxagentRealizeImage: WARNING! Visual not found. Using default visual.\n");
     #endif
-    
+
     pVisual = nxagentVisuals[nxagentDefaultVisualIndex].visual;
-  } 
+  }
 
   /*
    * Get bytes per line according to format.
@@ -1089,7 +1089,7 @@ FIXME: Should use an unpack resource here.
   if (client == NULL)
   {
     client = serverClient;
- 
+
     #ifdef TEST
     fprintf(stderr, "nxagentPutSubImage: WARNING! Using the server client with index [%d].\n",
                 client -> index);
@@ -1405,7 +1405,7 @@ FIXME: There should be a callback registered by the agent that
      * Add the image only if we have a valid checksum. This is the
      * case only if we originally tried to find the image in cache.
      */
-      
+
     if (NXImageCacheSize > 0 && packedChecksum != NULL)
     {
       #ifdef DEBUG
@@ -1608,7 +1608,7 @@ int nxagentScaleImage(int x, int y, unsigned xRatio, unsigned yRatio,
   if (newImage -> data == NULL)
   {
     SAFE_free(newImage);
-    
+
     #ifdef PANIC
     fprintf(stderr, "nxagentScaleImage: PANIC! Failed to create the target image data.\n");
     #endif
@@ -1703,4 +1703,3 @@ char *nxagentAllocateImageData(int width, int height, int depth, int *length, in
 
   return data;
 }
-
