@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -156,7 +156,7 @@ FIXME: These, if not removed, should at least be moved to Display.h
        and Display.c.
 */
 int nxagentBackingStore;
-int nxagentSaveUnder;
+Bool nxagentSaveUnder;
 
 /*
  * This is true at startup and set to the value of
@@ -173,7 +173,8 @@ int nxagentSaveUnder;
  */
 Bool nxagentDoFullGeneration = True;
 
- /*
+#ifdef X2GO
+/*
  * True if agent is running as X2goAgent
  * False if agent is running as NXAgent
  */
@@ -182,21 +183,54 @@ Bool nxagentX2go;
 /*
  * Check if agent is X2goAgent
  */
-void checkX2goAgent(void)
+void checkX2goAgent(int argc, char * argv[])
 {
   #ifdef TEST
   fprintf(stderr, "%s: nxagentProgName [%s]\n", __func__, nxagentProgName);
   #endif
 
+  nxagentX2go = False;
+
   if (strcasecmp(nxagentProgName,"x2goagent") == 0)
   {
-    fprintf(stderr, "\nrunning as X2Go Agent\n");
     nxagentX2go = True;
   }
   else
-    nxagentX2go = False;
+  {
+    char *envDisplay = getenv("DISPLAY");
+
+    /* x2go DISPLAY variable contains ".x2go" */
+    if (envDisplay && strstr(envDisplay, ".x2go-"))
+    {
+      nxagentX2go = True;
+    }
+    else
+    {
+      for (int i = 1; i < argc; i++)
+      {
+        /* x2go session names are passed with -name and start with "X2GO-" */
+        if (argv[i] && strncmp(argv[i], "-name", 5)  == 0)
+        {
+          if (i < argc - 1)
+          {
+            if (strstr(argv[i+1], "X2GO-"))
+            {
+              nxagentX2go = True;
+              break;
+            }
+          }
+        }
+      }
+    }
+  }
+
+  if (nxagentX2go)
+    fprintf(stderr, "\nrunning as X2Go Agent\n");
 }
 
+
+#endif
+
 /*
  * Called at X server's initialization.
  */
@@ -210,10 +244,10 @@ void InitOutput(ScreenInfo *scrInfo, int argc, char *argv[])
   {
     fprintf(stderr, "\nNXAGENT - Version " NX_VERSION_CURRENT_STRING "\n\n");
     fprintf(stderr, "Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)\n");
-    fprintf(stderr, "Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>\n");
-    fprintf(stderr, "Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>\n");
-    fprintf(stderr, "Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>\n");
-    fprintf(stderr, "Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>\n");
+    fprintf(stderr, "Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>\n");
+    fprintf(stderr, "Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>\n");
+    fprintf(stderr, "Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>\n");
+    fprintf(stderr, "Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>\n");
     fprintf(stderr, "Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)\n");
     fprintf(stderr, "See https://github.com/ArcticaProject/nx-libs for more information.\n\n");
 
@@ -235,7 +269,7 @@ void InitOutput(ScreenInfo *scrInfo, int argc, char *argv[])
    */
 
   if (nxagentOption(ImageRateLimit) != 0)
-  { 
+  {
     fprintf(stderr, "Info: Image rate limit set to %u kB/s.\n", nxagentOption(ImageRateLimit));
   }
 
@@ -346,10 +380,10 @@ FIXME: These variables, if not removed at all because have probably
 #else
   nxagentFontPrivateIndex = AllocateFontPrivateIndex();
 #endif /* HAS_XFONT2 */
-  RT_NX_FONT = CreateNewResourceType(nxagentDestroyNewFontResourceType); 
+  RT_NX_FONT = CreateNewResourceType(nxagentDestroyNewFontResourceType);
   nxagentClientPrivateIndex = AllocateClientPrivateIndex();
   nxagentPixmapPrivateIndex = AllocatePixmapPrivateIndex();
-  RT_NX_PIXMAP = CreateNewResourceType(nxagentDestroyNewPixmapResourceType); 
+  RT_NX_PIXMAP = CreateNewResourceType(nxagentDestroyNewPixmapResourceType);
 
   RT_NX_CORR_BACKGROUND = CreateNewResourceType(nxagentDestroyCorruptedBackgroundResource);
   RT_NX_CORR_WINDOW = CreateNewResourceType(nxagentDestroyCorruptedWindowResource);
