@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -40,13 +40,15 @@ is" without express or implied warranty.
 #ifndef __Init_H__
 #define __Init_H__
 
-extern int nxagentDoFullGeneration;
+extern Bool nxagentDoFullGeneration;
 
 extern int nxagentBackingStore;
-extern int nxagentSaveUnder;
+extern Bool nxagentSaveUnder;
 
-extern int nxagentX2go;
-void checkX2goAgent(void);
+#ifdef X2GO
+extern Bool nxagentX2go;
+void checkX2goAgent(int argc, char *argv[]);
+#endif
 
 extern ServerGrabInfoRec nxagentGrabServerInfo;
 
