@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -663,7 +663,8 @@ XkbError:
             #endif
             nxagentChangeOption(KeycodeConversion, KeycodeConversionOff);
 
-	    /*
+#ifdef X2GO
+            /*
              * when cloning we do not want X2Go to set the keyboard
              * via a keyboard file generated by nxagent. The defined
              * method for switching that off is the creation of a dir
@@ -692,6 +693,7 @@ XkbError:
             {
               nxagentWriteKeyboardFile(nxagentRemoteRules, nxagentRemoteModel, nxagentRemoteLayout, nxagentRemoteVariant, nxagentRemoteOptions);
             }
+#endif
           }
           nxagentKeycodeConversionSetup();
         }
@@ -1290,7 +1292,7 @@ void nxagentInitXkbWrapper(void)
 }
 
 void nxagentDisableXkbExtension(void)
-{  
+{
   #ifdef TEST
   fprintf(stderr, "%s: Called.\n", __func__);
   #endif
