@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -35,7 +35,7 @@
 #include "Options.h"
 #include "Keyboard.h"
 #include "Drawable.h"
-#include "Init.h" /* extern int nxagentX2go */
+#include "Init.h" /* extern Bool nxagentX2go */
 #include "Utils.h"
 
 #include <unistd.h>
@@ -314,11 +314,15 @@ void nxagentInitKeystrokes(Bool force)
 
   done = True;
 
+#ifdef X2GO
   if (nxagentX2go) {
     homefile = "/.x2go/config/keystrokes.cfg";
     etcfile = "/etc/x2go/keystrokes.cfg";
     envvar = "X2GO_KEYSTROKEFILE";
-  } else {
+  }
+  else
+#endif
+  {
     homefile = "/.nx/config/keystrokes.cfg";
     etcfile = "/etc/nxagent/keystrokes.cfg";
     envvar = "NXAGENT_KEYSTROKEFILE";
@@ -513,13 +517,13 @@ char *nxagentFindMatchingKeystrokes(char *name)
     {
       char *tmp;
       char *tmp1 = nxagentGetSingleKeystrokeString(cur);
-      if (-1 == asprintf(&tmp, "%s  %-*s : %s\n", res, maxlen,
+      if (-1 == asprintf(&tmp, "%s\n  %-*s : %s", res, maxlen,
                          nxagentSpecialKeystrokeNames[cur->stroke],
                          tmp1))
       {
         SAFE_free(tmp1);
         #ifdef TEST
-        fprintf(stderr, "%s: returning incomplete result:\n%s", __func__, res);
+        fprintf(stderr, "%s: returning incomplete result:%s\n", __func__, res);
         #endif
         return res;
       }
