@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -215,14 +215,16 @@ InitSelections(void)
       NumCurrentSelections += nxagentMaxSelections;
       CurrentSelections = newsels;
 
+      /* Note: these are the same values that will be set on a SelectionClear event */
+
       CurrentSelections[nxagentPrimarySelection].selection = XA_PRIMARY;
-      CurrentSelections[nxagentPrimarySelection].lastTimeChanged = ClientTimeToServerTime(0);
+      CurrentSelections[nxagentPrimarySelection].lastTimeChanged = ClientTimeToServerTime(CurrentTime);
       CurrentSelections[nxagentPrimarySelection].window = screenInfo.screens[0]->root->drawable.id;
       CurrentSelections[nxagentPrimarySelection].pWin = NULL;
       CurrentSelections[nxagentPrimarySelection].client = NullClient;
 
       CurrentSelections[nxagentClipboardSelection].selection = MakeAtom("CLIPBOARD", 9, 1);
-      CurrentSelections[nxagentClipboardSelection].lastTimeChanged = ClientTimeToServerTime(0);
+      CurrentSelections[nxagentClipboardSelection].lastTimeChanged = ClientTimeToServerTime(CurrentTime);
       CurrentSelections[nxagentClipboardSelection].window = screenInfo.screens[0]->root->drawable.id;
       CurrentSelections[nxagentClipboardSelection].pWin = NULL;
       CurrentSelections[nxagentClipboardSelection].client = NullClient;
@@ -548,7 +550,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
     nxagentFreeTimeoutTimer();
 
     /* FIXME: maybe move the code up to the KillAllClients() call to ddxBeforeReset? */
-    if ((dispatchException & DE_RESET) && 
+    if ((dispatchException & DE_RESET) &&
             (serverGeneration > nxagentMaxAllowedResets))
     {
         dispatchException &= ~DE_RESET;
@@ -566,7 +568,7 @@ Reply   Total	Cached	Bits In			Bits Out		Bits/Reply	  Ratio
        * error on the display and wait until the
        * NX transport is gone.
        */
-  
+
       fprintf(stderr, "Session: Terminating session at '%s'.\n", GetTimeAsString());
       saveAgentState("TERMINATING");
 
@@ -722,8 +724,8 @@ ProcConvertSelection(register ClientPtr client)
            (stuff->selection == MakeAtom("CLIPBOARD", 9, 0))) &&
                nxagentOption(Clipboard) != ClipboardNone)
     {
-      int i = nxagentFindCurrentSelectionIndex(stuff->selection);
-      if ((i < NumCurrentSelections) && (CurrentSelections[i].window != None))
+      int index = nxagentFindCurrentSelectionIndex(stuff->selection);
+      if ((index != -1) && (CurrentSelections[index].window != None))
       {
         if (nxagentConvertSelection(client, pWin, stuff->selection, stuff->requestor,
                                        stuff->property, stuff->target, stuff->time))
@@ -745,10 +747,15 @@ ProcConvertSelection(register ClientPtr client)
 	while ((i < NumCurrentSelections) && 
 	       CurrentSelections[i].selection != stuff->selection) i++;
 	if ((i < NumCurrentSelections) &&
-#ifdef NXAGENT_SERVER
-	    (CurrentSelections[i].window != None) && (CurrentSelections[i].client != NullClient)
-#else
 	    (CurrentSelections[i].window != None)
+#ifdef NXAGENT_SERVER
+            /*
+             * .window can be set and pointing to our server window to
+             * signal the clipboard owner being on the real X
+             * server. Therefore we need to check .client in addition
+             * to ensure having a local owner.
+             */
+	    && (CurrentSelections[i].client != NullClient)
 #endif
 #ifdef XCSECURITY
 	    && (!client->CheckAccess ||
