@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -88,6 +88,7 @@ void nxagentInitOptions(void)
   nxagentOptions.BackingStore = BackingStoreUndefined;
 
   nxagentOptions.Clipboard = ClipboardBoth;
+  nxagentOptions.TextClipboard = False;
 
   nxagentOptions.SharedMemory = True;
 
@@ -129,7 +130,7 @@ void nxagentInitOptions(void)
   nxagentOptions.DisplayBuffer  = UNDEFINED;
   nxagentOptions.DisplayCoalescence = 0;
 
-  nxagentOptions.Composite = True;
+  nxagentOptions.Composite = False;
 
   nxagentOptions.IgnoreVisibility = False;
 
