@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -194,6 +194,13 @@ typedef struct _AgentOptions
    */
   ClipboardMode Clipboard;
 
+  /*
+   * transfer TARGETS to remote side or answer with a limited
+   * hardcoded text target list
+   * Should be Bool but we'd have to include Xlib.h for that
+   */
+  int TextClipboard;
+
   /*
    * Enable agent to use the MITSHM extension in path from remote
    * proxy to the real X server.
@@ -227,7 +234,7 @@ typedef struct _AgentOptions
    */
   Bool Reset;
 
-  /* 
+  /*
    * Geometry of the agent root window, relative to the agent default
    * window.
    */
