@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXAGENT, NX protocol compression and NX extensions to this software    */
@@ -48,6 +48,12 @@
 #undef  TEST
 #undef  DEBUG
 
+#ifndef X2GO
+void nxagentShowSplashWindow(XlibWindow parentWindow) {}
+void nxagentPaintLogo(XlibWindow win, int scale, int width, int height) {}
+void nxagentRemoveSplashWindow(void) {}
+Bool nxagentHaveSplashWindow(void) {return False;}
+#else
 /*
  * Colors used to paint the splash screen.
  */
@@ -68,7 +74,7 @@ void nxagentShowSplashWindow(XlibWindow parentWindow)
   /*
    * Show splash window only when running as X2Go Agent
    */
-  if(!nxagentX2go)
+  if (!nxagentX2go)
     return;
 
   #ifdef TEST
@@ -344,6 +350,7 @@ void nxagentRemoveSplashWindow(void)
     nxagentSplashWindow = None;
     nxagentRefreshWindows(screenInfo.screens[0]->root);
 
+#ifdef NXAGENT_ONSTART
     #ifdef TEST
     fprintf(stderr, "%s: setting the ownership of %s (%d) on window [0x%lx]\n", __func__,
                 "NX_CUT_BUFFER_SERVER", (int)serverTransToAgentProperty, nxagentWindow(screenInfo.screens[0]->root));
@@ -351,6 +358,7 @@ void nxagentRemoveSplashWindow(void)
 
     XSetSelectionOwner(nxagentDisplay, serverTransToAgentProperty,
                            nxagentWindow(screenInfo.screens[0]->root), CurrentTime);
+#endif
   }
 
   if (nxagentPixmapLogo)
@@ -359,3 +367,4 @@ void nxagentRemoveSplashWindow(void)
     nxagentPixmapLogo = (XlibPixmap) 0;
   }
 }
+#endif /* ifdef X2GO */
