@@ -1,4 +1,4 @@
 #!/bin/sh
-where=`dirname $0`
+where=$(dirname $0)
 git ls-files | grep '\.[chm]$' | xargs sh "$where"/x-indent.sh
 
