@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXCOMP, NX protocol compression and NX extensions to this software     */
@@ -253,7 +253,7 @@ getComputerName() {
 
   const char *hostname = NULL;
 
-  #ifdef __CYGWIN32__
+  #if defined(__CYGWIN__) || defined(__CYGWIN32__)
 
   hostname = getenv("COMPUTERNAME");
 
