@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXCOMP, NX protocol compression and NX extensions to this software     */
@@ -216,7 +216,16 @@ int NXTransDialog(const char *caption, const char *message,
 
   UnsetEnv("LD_LIBRARY_PATH");
 
-  for (int i = 0; i < 2; i++)
+  if (!pulldown)
+  {
+    cerr << "Info: Upcoming dialog:\n"
+         << "/-----------------------------------------------------------\n"
+         << caption << ":\n"
+         << message << "\n"
+         << "\\-----------------------------------------------------------\n";
+  }
+
+  for (int i = 0; i < 4; i++)
   {
     if (local != 0)
     {
@@ -249,58 +258,63 @@ int NXTransDialog(const char *caption, const char *message,
       }
     }
 
-    #ifdef WARNING
+    #ifdef TEST
     *logofs << "NXTransDialog: WARNING! Couldn't start '"
             << command << "'. " << "Error is " << EGET()
             << " '" << ESTR() << "'.\n" << logofs_flush;
     #endif
 
+    #ifdef WARNING
     cerr << "Warning" << ": Couldn't start '" << command
          << "'. Error is " << EGET() << " '" << ESTR()
          << "'.\n";
+    #endif
 
     //
     // Retry by looking for the default name
     // in the default NX path.
     //
 
-    if (i == 0)
+    if (i == 0 || i == 2)
     {
-
       strcpy(command, "nxclient");
+    }
+    else if (i == 1 || i == 3)
+    {
+      strcpy(command, "nxdialog");
+    }
 
+    if (i == 2)
+    {
       char newPath[DEFAULT_STRING_LIMIT];
 
       strcpy(newPath, "/usr/NX/bin:/opt/NX/bin:/usr/local/NX/bin:");
 
       #ifdef __APPLE__
-
       // FIXME: missing length limitation!
       strcat(newPath, "/Applications/NX Client for OSX.app/Contents/MacOS:");
-
       #endif
 
-      #ifdef __CYGWIN32__
-
+      #if defined(__CYGWIN__) || defined(__CYGWIN32__)
       // FIXME: missing length limitation!
       strcat(newPath, ".:");
-
       #endif
 
       int newLength = strlen(newPath);
-
       char *oldPath = getenv("PATH");
 
       // FIXME: check if strncat would be better here
       snprintf(newPath + newLength, DEFAULT_STRING_LIMIT - newLength, "%s", oldPath);
 
-      #ifdef WARNING
+      #ifdef TEST
       *logofs << "NXTransDialog: WARNING! Trying with path '"
               << newPath << "'.\n" << logofs_flush;
       #endif
 
+      #ifdef WARNING
       cerr << "Warning" << ": Trying with path '" << newPath
            << "'.\n";
+      #endif
 
       //
       // Solaris doesn't seem to have
@@ -308,22 +322,36 @@ int NXTransDialog(const char *caption, const char *message,
       //
 
       #ifdef __sun
-
       char newEnv[DEFAULT_STRING_LIMIT + 5];
-
       sprintf(newEnv,"PATH=%s", newPath);
-
       putenv(newEnv);
-
       #else
-
       setenv("PATH", newPath, 1);
-
+      #endif
+    }
+    else
+    {
+      #ifdef TEST
+      *logofs << "NXTransDialog: WARNING! Trying with command '"
+              << command << "'.\n" << logofs_flush;
       #endif
 
+      #ifdef WARNING
+      cerr << "Warning" << ": Trying with command '" << command
+           << "'.\n";
+      #endif
     }
   }
 
+  #ifdef TEST
+  *logofs << "NXTransDialog: WARNING! Could not display dialog.\n"
+          << logofs_flush;
+  #endif
+
+  #ifdef WARNING
+  cerr << "Warning" << ": Could not display dialog.\n";
+  #endif
+
   //
   // Hopefully useless.
   //
@@ -477,7 +505,7 @@ int NXTransClient(const char* display)
 
       #endif
 
-      #ifdef __CYGWIN32__
+      #if defined(__CYGWIN__) || defined(__CYGWIN32__)
 
       strcat(newPath, ".:");
 
@@ -810,13 +838,13 @@ int NXTransKeeper(int caches, int images, const char *root)
   // must be copied in keeper's constructor
   // before control is deleted.
   //
-  
+
   MemoryCleanup("NXTransKeeper");
 
   //
   // Decrease the priority of this process.
   //
-  // The following applies to Cygwin: "Cygwin processes can be 
+  // The following applies to Cygwin: "Cygwin processes can be
   // set to IDLE_PRIORITY_CLASS, NORMAL_PRIORITY_CLASS, HIGH_-
   // PRIORITY_CLASS, or REALTIME_PRIORITY_CLASS with the nice
   // call. If you pass a positive number to nice(), then the
