@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXCOMP, NX protocol compression and NX extensions to this software     */
@@ -68,7 +68,7 @@ const int DEFAULT_LOOPBACK_BIND = 0;
 const int DEFAULT_NX_PROXY_PORT_OFFSET = 4000;
 
 //
-// Default TCP port used by client proxy to listen to  
+// Default TCP port used by client proxy to listen to
 // X clients and by server proxy to connect to remote.
 //
 
@@ -326,31 +326,36 @@ static const char UsageInfo[] =
                a program providing encryption of the point to point\n\
                communication.\n\
 \n\
-rootless=b\n\
-geometry=s\n\
-resize=b\n\
-fullscreen=b\n\
-keyboard=s\n\
-clipboard=s\n\
-streaming=n\n\
+autodpi=b\n\
+autograb=b\n\
 backingstore=n\n\
+client=s\n\
+clients=s\n\
+clipboard=s\n\
 composite=n\n\
-xinerama=n\n\
+copysize=n\n\
+defer=n\n\
+fullscreen=n\n\
+geometry=s\n\
+kbtype=s\n\
+keyboard=s\n\
+keyconv=s\n\
+magicpixel=b\n\
+menu=n\n\
+resize=b\n\
+rootless=b\n\
+shadow=n\n\
+shadowmode=s\n\
+shadowuid=n\n\
 shmem=b\n\
 shpix=b\n\
-kbtype=s\n\
-client=s\n\
-shadow=n\n\
-shadowuid=n\n\
-shadowmode=s\n\
-defer=n\n\
-tile=s\n\
-menu=n\n\
-magicpixel=n\n\
-autodpi=n\n\
 sleep=n\n\
+state=s\n\
+streaming=n\n\
+textclipboard=b\n\
+tile=s\n\
 tolerancechecks=s\n\
-keyconv=s\n\
+xinerama=b\n\
                These options are interpreted by the NX agent. They\n\
                are ignored by the proxy.\n\
 \n\
@@ -426,10 +431,10 @@ const char *GetUsageInfo()
 static const char CopyrightInfo[] =
 "\
 Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)\n\
-Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>\n\
-Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>\n\
-Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>\n\
-Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>\n\
+Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>\n\
+Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>\n\
+Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>\n\
+Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>\n\
 Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)\n\
 \n\
 NXCOMP, NX protocol compression and NX extensions to this software\n\
@@ -1902,11 +1907,11 @@ void DumpHexData(const unsigned char *buffer, unsigned int size)
 
   *logofs << message << logofs_flush;
 
-  // 
+  //
   // "Index    0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f  Ascii           "
   // "-----   -- -- -- -- -- -- -- -- -- -- -- -- -- -- -- --  ----------------"
   // "00000 : 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00 00  ................"
-  // 
+  //
 
   sprintf (message,"Index   0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f  Ascii           \n");
   *logofs << message << logofs_flush;
@@ -1924,7 +1929,7 @@ void DumpHexData(const unsigned char *buffer, unsigned int size)
     sprintf  (message,"%.5d  ", index);
 
     for (index_ascii = 0, linescan = index;
-             ((index < (linescan + 16)) && (index < size)); 
+             ((index < (linescan + 16)) && (index < size));
                   index++, index_ascii++)
     {
       if (isprint(buffer [index]))
@@ -1947,7 +1952,7 @@ void DumpHexData(const unsigned char *buffer, unsigned int size)
     sprintf  (&message [strlen (message)]," %s\n", ascii);
 
     *logofs << message << logofs_flush;
-  } 
+  }
 
   sprintf  (message,"\n####  End Dump Buffer ####\n\n");
 
