@@ -1,10 +1,10 @@
 /**************************************************************************/
 /*                                                                        */
 /* Copyright (c) 2001, 2011 NoMachine (http://www.nomachine.com)          */
-/* Copyright (c) 2008-2014 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
-/* Copyright (c) 2014-2016 Ulrich Sibiller <uli42@gmx.de>                 */
-/* Copyright (c) 2014-2016 Mihai Moldovan <ionic@ionic.de>                */
-/* Copyright (c) 2011-2016 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
+/* Copyright (c) 2008-2017 Oleksandr Shneyder <o.shneyder@phoca-gmbh.de>  */
+/* Copyright (c) 2014-2022 Ulrich Sibiller <uli42@gmx.de>                 */
+/* Copyright (c) 2014-2019 Mihai Moldovan <ionic@ionic.de>                */
+/* Copyright (c) 2011-2022 Mike Gabriel <mike.gabriel@das-netzwerkteam.de>*/
 /* Copyright (c) 2015-2016 Qindel Group (http://www.qindel.com)           */
 /*                                                                        */
 /* NXCOMP, NX protocol compression and NX extensions to this software     */
@@ -30,7 +30,7 @@
 #include <sys/types.h>
 #include <sys/utsname.h>
 
-#if defined(__CYGWIN32__) || defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
+#if defined(__CYGWIN__) || defined(__CYGWIN32__) || defined(__APPLE__) || defined(__FreeBSD__) || defined(__sun)
 #include <netinet/in_systm.h>
 #endif
 
@@ -65,7 +65,7 @@
 // disabled when running on MacOS/X.
 //
 
-#ifdef __CYGWIN32__
+#if defined(__CYGWIN__) || defined(__CYGWIN32__)
 #define TIOCOUTQ  ((unsigned int) -1)
 #endif
 
@@ -101,7 +101,7 @@ int GetKernelStep()
     // in the relevant OS dependent functions.
     //
 
-    #if defined(__CYGWIN32__) || defined(__APPLE__)
+    #if defined(__CYGWIN__) || defined(__CYGWIN32__) || defined(__APPLE__)
 
     _kernelStep = 0;
 
@@ -183,12 +183,12 @@ int GetKernelStep()
       }
     }
 
-    #endif /* #if defined(__CYGWIN32__) || defined(__APPLE__) */
+    #endif /* #if defined(__CYGWIN__) || defined(__CYGWIN32__) || defined(__APPLE__) */
   }
 
   return _kernelStep;
 }
-  
+
 int SetReuseAddress(int fd)
 {
   int flag = 1;
